==> haskell-th-lift-0.7.10-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-th-lift.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-lift
version: 0.7.10
id: th-lift-0.7.10-75yK075TwMmJKviRYN52Tn
key: th-lift-0.7.10-75yK075TwMmJKviRYN52Tn
license: BSD-3-Clause
copyright: © 2006 Ian Lynagh, © 2010-2018 Mathieu Boespflug
maintainer: Mathieu Boespflug <mboes@tweag.net>
author: Ian Lynagh
homepage: http://github.com/mboes/th-lift
synopsis: Derive Template Haskell'\''s Lift class for datatypes.
description:
    Derive Template Haskell'\''s Lift class for datatypes.
category: Language
abi: e672393602fcd52cff14eccc582720ac
exposed: True
exposed-modules:
    Language.Haskell.TH.Lift
import-dirs: /usr/lib/ghc-8.4.3/site-local/th-lift-0.7.10
library-dirs: /usr/lib/ghc-8.4.3/site-local/th-lift-0.7.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/th-lift-0.7.10
hs-libraries: HSth-lift-0.7.10-75yK075TwMmJKviRYN52Tn
depends:
    base-4.11.1.0 ghc-prim-0.5.2.0
    th-abstraction-0.2.6.0-8bhBYrrqrAJFCd9hjMrFb4
    template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
             th-abstraction-0.2.6.0-8bhBYrrqrAJFCd9hjMrFb4=033d711d7c9638e8bcc2f49549e04787
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
haddock-interfaces: /usr/share/doc/haskell-th-lift/html/th-lift.haddock
haddock-html: /usr/share/doc/haskell-th-lift/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-lift-0.7.10-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-th-lift.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-lift
version: 0.7.10
id: th-lift-0.7.10-6OYdru9agr89d2Y9kGBSW6
key: th-lift-0.7.10-6OYdru9agr89d2Y9kGBSW6
license: BSD-3-Clause
copyright: © 2006 Ian Lynagh, © 2010-2018 Mathieu Boespflug
maintainer: Mathieu Boespflug <mboes@tweag.net>
author: Ian Lynagh
homepage: http://github.com/mboes/th-lift
synopsis: Derive Template Haskell'\''s Lift class for datatypes.
description:
    Derive Template Haskell'\''s Lift class for datatypes.
category: Language
abi: 58c168757568e00e90992c0851334bed
exposed: True
exposed-modules:
    Language.Haskell.TH.Lift
import-dirs: /usr/lib/ghc-8.4.3/site-local/th-lift-0.7.10
library-dirs: /usr/lib/ghc-8.4.3/site-local/th-lift-0.7.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/th-lift-0.7.10
hs-libraries: HSth-lift-0.7.10-6OYdru9agr89d2Y9kGBSW6
depends:
    base-4.11.1.0 ghc-prim-0.5.2.0
    th-abstraction-0.2.7.0-K3VY5rzhCFL2FVEMFfolof
    template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
             th-abstraction-0.2.7.0-K3VY5rzhCFL2FVEMFfolof=e161720940186da8d7d7f15cc4c214a9
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
haddock-interfaces: /usr/share/doc/haskell-th-lift/html/th-lift.haddock
haddock-html: /usr/share/doc/haskell-th-lift/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
